"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAssociatedToken = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const hooked_1 = require("../../hooked");
const accounts_1 = require("../accounts");
function createAssociatedToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splAssociatedToken', 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL');
    const payerAccount = input.payer ?? context.payer;
    const ownerAccount = input.owner ?? context.identity.publicKey;
    const mintAccount = input.mint;
    const ataAccount = input.ata ??
        (0, hooked_1.findAssociatedTokenPda)(context, {
            owner: (0, umi_1.publicKey)(ownerAccount),
            mint: (0, umi_1.publicKey)(mintAccount),
        });
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: ataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ataAccount, true),
    });
    keys.push({
        pubkey: ownerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ownerAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = new Uint8Array();
    const bytesCreatedOnChain = (0, accounts_1.getTokenSize)() + umi_1.ACCOUNT_HEADER_SIZE;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createAssociatedToken = createAssociatedToken;
//# sourceMappingURL=createAssociatedToken.js.map