"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extendLut = exports.getExtendLutInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getExtendLutInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u32()],
        ['addresses', s.array(s.publicKey(), { size: s.u64() })],
    ], { description: 'ExtendLutInstructionData' }), (value) => ({ ...value, discriminator: 2 }));
}
exports.getExtendLutInstructionDataSerializer = getExtendLutInstructionDataSerializer;
function extendLut(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splAddressLookupTable', 'AddressLookupTab1e1111111111111111111111111');
    const addressAccount = input.address;
    const authorityAccount = input.authority ?? context.identity;
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: addressAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(addressAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getExtendLutInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.extendLut = extendLut;
//# sourceMappingURL=extendLut.js.map