"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mintTokensToChecked = exports.getMintTokensToCheckedInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getMintTokensToCheckedInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['amount', s.u64()],
        ['decimals', s.u8()],
    ], { description: 'MintTokensToCheckedInstructionData' }), (value) => ({ ...value, discriminator: 14 }));
}
exports.getMintTokensToCheckedInstructionDataSerializer = getMintTokensToCheckedInstructionDataSerializer;
function mintTokensToChecked(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA');
    const mintAccount = input.mint;
    const tokenAccount = input.token;
    const mintAuthorityAccount = input.mintAuthority;
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    const data = getMintTokensToCheckedInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.mintTokensToChecked = mintTokensToChecked;
//# sourceMappingURL=mintTokensToChecked.js.map